pub struct InitMigration;Expand description
Initial migration that creates the core database schema for Evento.
This migration creates the following database objects:
Event Table
The main table for storing domain events with the following columns:
id- Event identifier (ULID format, VARCHAR(26))name- Event type name (VARCHAR(50))aggregator_type- Aggregate root type (VARCHAR(50))aggregator_id- Aggregate root instance ID (VARCHAR(26))version- Event sequence number within the aggregatedata- Serialized event payload (BLOB)metadata- Serialized event metadata (BLOB)routing_key- Optional routing key for partitioning (VARCHAR(50))timestamp- Event timestamp in seconds (BIGINT)
Event Indexes
Several indexes are created for efficient querying:
idx_event_type- Index onaggregator_typeidx_event_type_id- Composite index on(aggregator_type, aggregator_id)idx_event_routing_key_type- Composite index on(routing_key, aggregator_type)- Unique constraint on
(aggregator_type, aggregator_id, version)
Snapshot Table
Table for storing aggregate snapshots (note: dropped in M0003):
id- Snapshot identifiertype- Snapshot typecursor- Event stream cursorrevision- Revision identifierdata- Serialized snapshot data- Primary key: composite
(type, id)
Subscriber Table
Table for tracking event subscription state:
key- Subscriber identifier (primary key)worker_id- Associated worker IDcursor- Current event stream positionlag- Subscription lag counterenabled- Whether subscription is activecreated_at/updated_at- Timestamps